#include "vector.h"

#include <iostream>
#include <thread>
#include <chrono>

#include <QtTest/QtTest>

class TestVector : public QObject
{
    Q_OBJECT

private slots:
    void testConstructor()
    {
        Vector v1;
        QVERIFY( v1.getElementCount() == DefaultElementCount );
        Vector v2( 4 );
        QVERIFY( v2.getElementCount() == 4 );
    }

    void testDeconstructor()
    {
        for (long i=0; i<50000000; i++)
            Vector v( 100 );
    }

    void testCopy()
    {
        Vector v1( 4 );
        QVERIFY( v1.getElementCount() == 4 );
        v1[0] = 2.72;
        v1[1] = 3.14;
        v1[2] = 9.80;
        v1[3] = 0.577;
        Vector v2( v1 );
        QVERIFY( v2.getElementCount() == 4 );
        QVERIFY( v2[0] == v1[0] );
        QVERIFY( v2[1] == v1[1] );
        QVERIFY( v2[2] == v1[2] );
        QVERIFY( v2[3] == v1[3] );
    }

    void testMult()
    {
        Vector v1( 4 );
        QVERIFY( v1.getElementCount() == 4 );
        v1[0] = 2.72;
        v1[1] = 3.14;
        v1[2] = 9.80;
        v1[3] = 0.577;
        Vector v2( v1 * 2.0 );
        QVERIFY( v2.getElementCount() == 4 );
        QVERIFY( v2[0] == v1[0]*2.0 );
        QVERIFY( v2[1] == v1[1]*2.0 );
        QVERIFY( v2[2] == v1[2]*2.0 );
        QVERIFY( v2[3] == v1[3]*2.0 );
    }
};

QTEST_GUILESS_MAIN(TestVector)
#include "test_vector.moc"
